# Synchronization folders script

[![Codacy Badge](https://app.codacy.com/project/badge/Grade/fd161c5c72334c50a06ccfb8d50027ae)](https://www.codacy.com/manual/mezgoodle/sync-folders?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=mezgoodle/sync-folders&amp;utm_campaign=Badge_Grade)

This is file for synchronization two folders by checking date of changing files inside. There are some option. Also create `logs.txt` file

## Usage
```bash
python main.py
```
